@@ -1,35 +1,9 @@
 package XML::XSS::Comment;
 BEGIN {
-  $XML::XSS::Comment::VERSION = '0.1_0';
+  $XML::XSS::Comment::VERSION = '0.1_1';
 }
+# ABSTRACT: XML::XSS comment stylesheet rule
 
-=head1 NAME 
-
-XML::XSS::Comment - XML::XSS comment stylesheet rule
-
-=head1 VERSION
-
-version 0.1_0
-
-=head1 SYNOPSIS
-
-    use XML::XSS;
-
-    my $xss = XML::XSS->new;
-
-    my $cmt_style = $xss->comment;
-
-    $cmt_style->set_filter( sub { s/^/#/gm; $_ } );
-
-    print $xss->render( '<doc><!-- foo -->yadah yadah</doc>' );
-
-
-=head1 DESCRIPTION
-
-A C<XML::XSS> rule that matches against the comment nodes of a
-document to be rendered.  
-
-=cut
 
 use 5.10.0;
 
@@ -41,23 +15,6 @@ with 'XML::XSS::Role::Renderer';
 no warnings qw/ uninitialized /;
 
 
-=head1 RENDERING ATTRIBUTES
-
-For a document, the displayed attributes follow the template:
-
-    pre
-    [text]
-    post
-
-=head2 process, pre, showtag, rename, post 
-
-Same attribute behaviors as in C<XML::XSS::Element>.
-
-=head2 replace, filter
-
-Same attribute behaviors as in C<XML::XSS::Text>.
-
-=cut 
 
 has [ qw/ showtag pre post rename replace process filter / ] => ( traits => [ qw/ XML::XSS::Role::StyleAttribute / ] );
 
@@ -101,4 +58,64 @@ sub apply {
     return $output;
 }
 
-1;
\ No newline at end of file
+1;
+
+
+
+__END__
+=pod
+
+=head1 NAME
+
+XML::XSS::Comment - XML::XSS comment stylesheet rule
+
+=head1 VERSION
+
+version 0.1_1
+
+=head1 SYNOPSIS
+
+    use XML::XSS;
+
+    my $xss = XML::XSS->new;
+
+    my $cmt_style = $xss->comment;
+
+    $cmt_style->set_filter( sub { s/^/#/gm; $_ } );
+
+    print $xss->render( '<doc><!-- foo -->yadah yadah</doc>' );
+
+=head1 DESCRIPTION
+
+A C<XML::XSS> rule that matches against the comment nodes of a
+document to be rendered.  
+
+=head1 RENDERING ATTRIBUTES
+
+For a document, the displayed attributes follow the template:
+
+    pre
+    [text]
+    post
+
+=head2 process, pre, showtag, rename, post 
+
+Same attribute behaviors as in C<XML::XSS::Element>.
+
+=head2 replace, filter
+
+Same attribute behaviors as in C<XML::XSS::Text>.
+
+=head1 AUTHOR
+
+  Yanick Champoux <yanick@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2010 by Yanick Champoux.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
