@@ -1,37 +1,9 @@
 package XML::XSS::Text;
 BEGIN {
-  $XML::XSS::Text::VERSION = '0.1_0';
+  $XML::XSS::Text::VERSION = '0.1_1';
 }
+# ABSTRACT: XML::XSS text stylesheet rule
 
-=head1 NAME 
-
-XML::XSS::Text - XML::XSS text stylesheet rule
-
-=head1 VERSION
-
-version 0.1_0
-
-=head1 SYNOPSIS
-
-
-    use XML::XSS;
-
-    my $xss = XML::XSS->new;
-
-    my $txt_style = $xss->text;
-
-    $txt_style->set_pre( "=pod\n" );
-    $txt_style->set_post( "=cut\n" );
-
-    print $xss->render( '<doc>yadah yadah</doc>' );
-
-
-=head1 DESCRIPTION
-
-A C<XML::XSS> rule that matches against the text nodes of a
-document to be rendered.  
-
-=cut
 
 
 use Moose;
@@ -41,60 +13,18 @@ with 'XML::XSS::Role::Renderer';
 
 no warnings qw/ uninitialized /;
 
-=head1 RENDERING ATTRIBUTES
 
-For a document, the displayed attributes follow the template:
-
-    pre
-    [text]
-    post
-
-=cut 
-
-=head2 pre
-
-Printed before the text.
-
-=head3 getter - pre()        
-
-=head3 setter - set_pre( $pre )
-
-=head2 replace 
-
-If defined, its value is used instead of the original text.
-
-=cut
 
 has replace => ( 
     traits => [ qw/ XML::XSS::Role::StyleAttribute / ] 
 );
 
-=head2 filter
-
-Can only accept a sub reference. If defined, the text will be passed 
-to the function as C<$_> and the returned value will be printed out.  Still is applied
-even if C<replace> is used.
-
-    $xss->set( '#text', {
-        filter => sub { uc },
-    } );
-
-=cut
 
 has filter => (
     traits => [ qw/ XML::XSS::Role::StyleAttribute / ] 
 );
 
 
-=head2 post
-
-Printed after the text.
-
-=head3 getter - post()        
-
-=head3 setter - set_post( $post )
-
-=cut
 
 has [ qw/ pre post / ] => (
     traits => [ qw/ XML::XSS::Role::StyleAttribute / ] 
@@ -135,4 +65,87 @@ sub apply {
     return $output;
 }
 
-1;
\ No newline at end of file
+1;
+
+
+
+__END__
+=pod
+
+=head1 NAME
+
+XML::XSS::Text - XML::XSS text stylesheet rule
+
+=head1 VERSION
+
+version 0.1_1
+
+=head1 SYNOPSIS
+
+    use XML::XSS;
+
+    my $xss = XML::XSS->new;
+
+    my $txt_style = $xss->text;
+
+    $txt_style->set_pre( "=pod\n" );
+    $txt_style->set_post( "=cut\n" );
+
+    print $xss->render( '<doc>yadah yadah</doc>' );
+
+=head1 DESCRIPTION
+
+A C<XML::XSS> rule that matches against the text nodes of a
+document to be rendered.  
+
+=head1 RENDERING ATTRIBUTES
+
+For a document, the displayed attributes follow the template:
+
+    pre
+    [text]
+    post
+
+=head2 pre
+
+Printed before the text.
+
+=head3 getter - pre()        
+
+=head3 setter - set_pre( $pre )
+
+=head2 replace 
+
+If defined, its value is used instead of the original text.
+
+=head2 filter
+
+Can only accept a sub reference. If defined, the text will be passed 
+to the function as C<$_> and the returned value will be printed out.  Still is applied
+even if C<replace> is used.
+
+    $xss->set( '#text', {
+        filter => sub { uc },
+    } );
+
+=head2 post
+
+Printed after the text.
+
+=head3 getter - post()        
+
+=head3 setter - set_post( $post )
+
+=head1 AUTHOR
+
+  Yanick Champoux <yanick@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2010 by Yanick Champoux.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
